@@ -15,6 +15,7 @@ from .v3.device_monitoring import DeviceMonitoring
 from .v3.extensions import Extensions
 from .v3.groups import Groups
 from .v3.lifecycle_management import LifecycleManagement
+from .v3.observations import Observations
 from .v3.resources import Resources
 from .v3.sessions import Sessions
 from .v3.setting_values import SettingValues
@@ -29,6 +30,7 @@ class Coiote:
     """
     Represents a connection to Coiote server.
     """
+    SUPPORTED_API_VERSIONS = {"v3"}
 
     def __init__(
             self,
@@ -39,7 +41,7 @@ class Coiote:
     ):
         self.url = url
         self.api_version = api_version
-        if self.api_version not in {"v3"}:
+        if self.api_version not in Coiote.SUPPORTED_API_VERSIONS:
             raise ValueError("Only v3 API is supported right now")
         self.api_url = f"{url}/api/coiotedm/{api_version}"
         self.session = requests.Session()
@@ -60,6 +62,7 @@ class Coiote:
         self.extensions: Extensions = self._make_module(Extensions)
         self.groups: Groups = self._make_module(Groups)
         self.lifecycle_management: LifecycleManagement = self._make_module(LifecycleManagement)
+        self.observations: Observations = self._make_module(Observations)
         self.resources: Resources = self._make_module(Resources)
         self.sessions: Sessions = self._make_module(Sessions)
         self.setting_values: SettingValues = self._make_module(SettingValues)
