@@ -10,11 +10,11 @@ class DataModel(ApiEndpoint):
     ):
         super().__init__(*args, **kwargs, api_url="cachedDataModels")
 
-    @api_call(DeviceDataEntry)
-    def get_device_datamodel(self, device_id: str, parameters=[]) -> List[DeviceDataEntry]:
-        return self.session.get(super()._make_url(f"/{device_id}"), params={"parameters": parameters})
+    @api_call(List[DeviceDataEntry])
+    def get_device_datamodel(self, device_id: str, parameters=None):
+        if parameters is None:
+            parameters = []
+        return self.session.get(self.get_url(f"/{device_id}"), params={"parameters": parameters})
 
     def get_device_parameter(self, device_id: str, parameter_key: str) -> List[DeviceDataEntry]:
-        datamodel = self.get_device_datamodel(
-            device_id=device_id, parameters=[parameter_key])
-        return datamodel
+        return self.get_device_datamodel(device_id, [parameter_key])
