@@ -1,6 +1,6 @@
 from dataclasses import asdict
 
-from coiote.utils import ApiEndpoint, api_call
+from coiote.utils import ApiEndpoint, api_call_raw
 from coiote.v3.model.lifecycle_management import FactoryTestingRequest
 
 
@@ -10,10 +10,10 @@ class LifecycleManagement(ApiEndpoint):
     ):
         super().__init__(*args, **kwargs, api_url="deviceLifecycleManagement")
 
-    @api_call()
+    @api_call_raw
     def activate_factory_testing(self, data: FactoryTestingRequest):
         return self.session.post(self.get_url("/factoryTesting/activate"), json=asdict(data))
 
-    @api_call()
+    @api_call_raw
     def deactivate_factory_testing(self, data: FactoryTestingRequest):
         return self.session.post(self.get_url("/factoryTesting/deactivate"), json=asdict(data))
