@@ -20,3 +20,8 @@ class MonitoringDataResponse:
     lastPointTimestamp: Optional[datetime] = field(default=None)
     metadata: Dict[str, str] = field(default_factory=dict)
     data: List[Datapoint] = field(default_factory=list)
+
+@dataclass
+class SetResourceAliasRequest:
+    lwm2mUrl: str
+    alias: str
\ No newline at end of file
