@@ -1,6 +1,6 @@
 from typing import Optional
 
-from coiote.utils import ApiEndpoint, api_call, sanitize_request_param
+from coiote.utils import ApiEndpoint, sanitize_request_param, api_call_raw
 
 
 class Sessions(ApiEndpoint):
@@ -9,7 +9,7 @@ class Sessions(ApiEndpoint):
     ):
         super().__init__(*args, **kwargs, api_url="sessions")
 
-    @api_call()
+    @api_call_raw
     def start_for_device(self, device_id: str, task_id: Optional[str] = None, allow_deregistered=False):
         device_id = sanitize_request_param(device_id)
         params = {"taskId": task_id}
