@@ -1,6 +1,8 @@
 from dataclasses import asdict
 
-from coiote.utils import ApiEndpoint, api_call, sanitize_request_param
+from requests import Response
+
+from coiote.utils import ApiEndpoint, api_call, sanitize_request_param, api_call_raw
 from coiote.v3.model.tasks import *
 
 
@@ -10,23 +12,23 @@ class Tasks(ApiEndpoint):
     ):
         super().__init__(*args, **kwargs, api_url="tasks")
 
-    @api_call()
-    def run_device_config_task(self, device_id: str, task_definition: ConfigurationTaskDefinition) -> str:
+    @api_call(str)
+    def run_device_config_task(self, device_id: str, task_definition: ConfigurationTaskDefinition) -> Response:
         return self.session.post(self.get_url(f"/configure/{device_id}"),
                                  json={'taskDefinition': asdict(task_definition)})
 
-    @api_call()
-    def get_all(self, search_criteria: Optional[str] = None) -> List[str]:
+    @api_call(List[str])
+    def get_all(self, search_criteria: Optional[str] = None) -> Response:
         params = {"searchCriteria": search_criteria}
         return self.session.get(self.get_url(), params=params)
 
-    @api_call()
+    @api_call_raw
     def delete_callback(self, task_id: str, callback_id: str):
         task_id = sanitize_request_param(task_id)
         callback_id = sanitize_request_param(callback_id)
         return self.session.delete(self.get_url(f"/callback/{task_id}/{callback_id}"))
 
-    @api_call()
+    @api_call(str)
     def run_device_fota_task(self,
                              device_id: str,
                              firmware_resource_id: str,
@@ -40,7 +42,7 @@ class Tasks(ApiEndpoint):
                              check_delivery_and_protocol: bool = True,
                              resume_after_downlink_failure: bool = False,
                              execute_immediately: bool = False
-                             ) -> str:
+                             ) -> Response:
         params = {
             "executeImmediately": execute_immediately,
             "resumeAfterDownlinkFailure": resume_after_downlink_failure,
@@ -57,17 +59,17 @@ class Tasks(ApiEndpoint):
         firmware_resource_id = sanitize_request_param(firmware_resource_id)
         return self.session.post(self.get_url(f"/upgrade/{device_id}/{firmware_resource_id}"), params=params)
 
-    @api_call()
-    def get_one(self, task_id: str) -> Task:
+    @api_call(Task)
+    def get_one(self, task_id: str) -> Response:
         task_id = sanitize_request_param(task_id)
         return self.session.get(self.get_url(f"/{task_id}"))
 
-    @api_call()
+    @api_call_raw
     def update_one(self, task_id: str, config: TaskConfig):
         task_id = sanitize_request_param(task_id)
         return self.session.put(self.get_url(f"/{task_id}"), json=asdict(config))
 
-    @api_call()
+    @api_call_raw
     def delete_one(self, task_id: str):
         task_id = sanitize_request_param(task_id)
         return self.session.delete(self.get_url(f"/{task_id}"))
